PROCESS_PER_MONITOR_DPI_AWARE constant
Per monitor DPI aware. This app checks for the DPI when it is created and adjusts the scale factor whenever the DPI changes. These applications are not automatically scaled by the system.
Implementation
@Deprecated('Use PROCESS_PER_MONITOR_DPI_AWARE instead')
static const PROCESS_PER_MONITOR_DPI_AWARE = 2;