SSSPTRelativeToEnd constant
Calculates the stream offset relative from the end of the stream.
Implementation
@Deprecated('Use SSSPTRelativeToEnd instead')
static const SSSPTRelativeToEnd = 2;
Calculates the stream offset relative from the end of the stream.
@Deprecated('Use SSSPTRelativeToEnd instead')
static const SSSPTRelativeToEnd = 2;